/**
 * Copyright (C) 2007-2013 Lawrence Murray
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 * 
 * @author Lawrence Murray <lawrence@indii.org>
 * @version $Rev: 500 $
 * @date $Date: 2013-08-16 19:04:13 +0800 (Fri, 16 Aug 2013) $
 */
#include "../Components.hpp"

using namespace indii;

bool Components::isActivated(const Component c) {
  return true;
}

bool Components::needsReactivation(const Component c) {
  return false;
}

bool Components::isTrial(const Component c) {
  return false;
}

bool Components::activate(const Component c, const wxString& key) {
  return false;
}

int Components::daysLeft() {
  return 0;
}

int Components::maxDays() {
  return 21;
}

wxString Components::getKey() {
  return wxEmptyString;
}
